@@ -3,9 +3,10 @@ package config
 // Templates holds the configurations to override the default
 // templates used to render the schema and the docs.
 type Templates struct {
-	MD   MD   `yaml:"md,omitempty"`
-	Dot  Dot  `yaml:"dot,omitempty"`
-	PUML PUML `yaml:"puml,omitempty"`
+	MD      MD      `yaml:"md,omitempty"`
+	Dot     Dot     `yaml:"dot,omitempty"`
+	PUML    PUML    `yaml:"puml,omitempty"`
+	Mermaid Mermaid `yaml:"mermaid,omitempty"`
 }
 
 // MD holds the paths to the markdown template files.
@@ -28,3 +29,10 @@ type PUML struct {
 	Schema string `yaml:"schema,omitempty"`
 	Table  string `yaml:"table,omitempty"`
 }
+
+// Mermaid holds the paths to the Mermaid template files.
+// If populated the files are used to override the default ones.
+type Mermaid struct {
+	Schema string `yaml:"schema,omitempty"`
+	Table  string `yaml:"table,omitempty"`
+}
