@@ -2,10 +2,8 @@ package plantuml
 
 import (
 	"embed"
-	"fmt"
 	"io"
 	"os"
-	"strings"
 	"text/template"
 
 	"github.com/k1LoW/tbls/config"
@@ -65,13 +63,6 @@ func (p *PlantUML) tableTemplate() (string, error) {
 
 // OutputSchema output dot format for full relation.
 func (p *PlantUML) OutputSchema(wr io.Writer, s *schema.Schema) error {
-	for _, t := range s.Tables {
-		err := addPrefix(t)
-		if err != nil {
-			return err
-		}
-	}
-
 	ts, err := p.schemaTemplate()
 	if err != nil {
 		return errors.WithStack(err)
@@ -92,15 +83,9 @@ func (p *PlantUML) OutputSchema(wr io.Writer, s *schema.Schema) error {
 // OutputTable output dot format for table.
 func (p *PlantUML) OutputTable(wr io.Writer, t *schema.Table) error {
 	tables, relations, err := t.CollectTablesAndRelations(*p.config.ER.Distance, true)
-
 	if err != nil {
 		return errors.WithStack(err)
 	}
-	for _, t := range tables {
-		if err := addPrefix(t); err != nil {
-			return errors.WithStack(err)
-		}
-	}
 	ts, err := p.tableTemplate()
 	if err != nil {
 		return errors.WithStack(err)
@@ -119,26 +104,3 @@ func (p *PlantUML) OutputTable(wr io.Writer, t *schema.Table) error {
 
 	return nil
 }
-
-func addPrefix(t *schema.Table) error {
-	// PRIMARY KEY
-	for _, i := range t.Indexes {
-		if !strings.Contains(i.Def, "PRIMARY") {
-			continue
-		}
-		for _, c := range i.Columns {
-			column, err := t.FindColumnByName(c)
-			if err != nil {
-				return err
-			}
-			column.Name = fmt.Sprintf("+ %s", column.Name)
-		}
-	}
-	// Foreign Key (Relations)
-	for _, c := range t.Columns {
-		if len(c.ParentRelations) > 0 && !strings.Contains(c.Name, "+") {
-			c.Name = fmt.Sprintf("# %s", c.Name)
-		}
-	}
-	return nil
-}
